/******************************************************************************
 * Copyright 2013, Qualcomm Innovation Center, Inc.
 *
 *    All rights reserved.
 *    This file is licensed under the 3-clause BSD license in the NOTICE.txt
 *    file for this project. A copy of the 3-clause BSD license is found at:
 *
 *        http://opensource.org/licenses/BSD-3-Clause.
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the license is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the license for the specific language governing permissions and
 *    limitations under the license.
 ******************************************************************************/

#import <Foundation/Foundation.h>

/**
 * The FTMFileAnnouncementReceivedDelegate can be utilized so the developer is notified
 * that an array of announced files has been received from a session peer. This delegate
 * is entirely optional but is necessary if the developer wishes to be able to send 
 * announcement requests to session peers.
 * 
 * See [FTMFileTransferModule setFileAnnouncementReceivedDelegate:].
 */
@protocol FTMFileAnnouncementReceivedDelegate <NSObject>

@required

/** @name Required Methods */

/**
 * Triggered when an announcement is received and notifies the user which files are now available for transfer.
 *
 * @param fileList Array of files available for transfer.
 * @param isFileIDResponse Indicates whether the announcement received is in response to an offer request.
 */
-(void)receivedAnnouncementForFiles: (NSArray *)fileList andIsFileIDResponse: (BOOL)isFileIDResponse;

@end
